@@ -2,6 +2,7 @@ mod build;
 mod create;
 mod delete;
 mod edit;
+mod export;
 mod info;
 mod list;
 
@@ -9,5 +10,6 @@ pub use build::build;
 pub use create::create;
 pub use delete::delete;
 pub use edit::edit;
+pub use export::export;
 pub use info::info;
 pub use list::list;
